@@ -57,6 +57,25 @@ class Client(object):
             payload=body,
         ).json()
 
+    def patch(self, route, params, body):
+        """ Sends a PATCH HTTP request
+
+        Args:
+            route (str): String with the route to the endpoint
+            params (tuple): Tuple with optional parameters of the request to send
+            body (dict): Dict with the body of the request to send
+
+        Return:
+            **response**: Returns the response object
+        """
+
+        return self._send_request(
+            verb="PATCH",
+            url="{url}{route}".format(url=self.base_url, route=route),
+            params=params,
+            payload=body,
+        ).json()
+
     def _send_request(self, verb, url, payload=None, params={}):
         """send the API request using the *requests.request* method
 
