@@ -11,22 +11,24 @@ class Session():
     @classmethod
     def create(cls):
 
-        route = '/v0/login-api'
+        route = '/v2/login-api'
 
-        login_params = (
-            ('username', os.getenv('MM_USER')),
-            ('password', os.getenv('MM_PASSWORD')),
-            ('domain', os.getenv('MM_DOMAIN')),
-        )
+        login_params = {
+            'domain': os.getenv('MM_DOMAIN')
+        }
+        auth_data = {
+            'username': os.getenv('MM_USER'),
+            'password': os.getenv('MM_PASSWORD'),
+        }
 
-        if login_params[0][1] is None:
+        if auth_data['username'] is None:
             raise MissingLoginCredentialsError('MM_USER')
-        elif login_params[1][1] is None:
+        elif auth_data['password'] is None:
             raise MissingLoginCredentialsError('MM_PASSWORD')
-        elif login_params[2][1] is None:
+        elif login_params['domain'] is None:
             raise MissingLoginCredentialsError('MM_DOMAIN')
 
-        session = Client().post(route=route, params=login_params, body={})
+        session = Client().post(route=route, params=login_params, body=auth_data)
 
         if not session["sessionId"]:
             raise AutenthicationError
